@@ -166,6 +166,7 @@ class NumerousLogHandler:
 class NumerousClient:
     def __init__(self, job_id=None, project=None, scenario=None, server=None, port=None, token=None, clear_data=None, no_log=False):
 
+
         self.job_states = JobStatus
         self._project = get_env(project, 'NUMEROUS_PROJECT')
         self._scenario = get_env(scenario, 'NUMEROUS_SCENARIO')
@@ -938,6 +939,8 @@ class RepeatedFunction:
 
 class NumerousAdminClient(NumerousClient):
     def __init__(self, token=None, server=None, port=None):
+        self._user = 'test_user'
+        self._organization = 'EnergyMachines'
 
         self._token = get_env(token, 'NUMEROUS_API_TOKEN')
 
@@ -953,6 +956,7 @@ class NumerousAdminClient(NumerousClient):
 
         log.info('init admin client')
 
+    """
     # TODO: Remove? The client should not be allowed to stop/start instances of clients!
     def start_image(self, scenario, image, name, namespace, spm_job_id, google_project='simulationwidgets'):
         deployed_image = self._job_manager.StartImage(spm_pb2.ImageInformation(
@@ -962,21 +966,21 @@ class NumerousAdminClient(NumerousClient):
             spm_job_id=spm_job_id
         ))
 
-        return {'kubernetes_id': deployed_image.kubernetes_id, 'namespace': deployed_image.namespace}
+        return {'kubernetes_id': deployed_image.kubernetes_id, 'namespace': deployed_image.namespace}"""
 
     def launch_job(self, project, scenario, job):
         self._job_manager.StartJob(spm_pb2.Job(
-            project_id=project, scenario_id=scenario, job_id=job
+            project_id=project, scenario_id=scenario, job_id=job, user_id=self._user, organization_id=self._organization
         ))
 
     def terminate_job(self, project, scenario, job):
         terminated_job = self._job_manager.TerminateJob(spm_pb2.Job(
-            project_id=project, scenario_id=scenario, job_id=job
+            project_id=project, scenario_id=scenario, job_id=job, user_id=self._user, organization_id=self._organization
         ))
 
     def reset_job(self, project, scenario, job):
         reset_job = self._job_manager.ResetJob(spm_pb2.Job(
-            project_id=project, scenario_id=scenario, job_id=job
+            project_id=project, scenario_id=scenario, job_id=job, user_id=self._user, organization_id=self._organization
         ))
 
 
